@@ -2,17 +2,13 @@ package Plack::Session::Store::Null;
 use strict;
 use warnings;
 
-our $VERSION   = '0.03';
+our $VERSION   = '0.10';
 our $AUTHORITY = 'cpan:STEVAN';
 
 sub new     { bless {} => shift }
 sub fetch   {}
 sub store   {}
-sub delete  {}
-sub cleanup {}
-sub persist {}
-
-sub dump_session { +{} }
+sub remove  {}
 
 1;
 
